@@ -3,6 +3,7 @@ import ckan.model as model
 import click
 
 from .figshare import figshare
+from .internal import internal
 
 
 @click.command()
@@ -12,6 +13,13 @@ def import_figshare(limit):
     figshare(limit=limit)
 
 
+@click.command()
+@click.option('--limit', default=0, help='Limit number of datasets imported')
+def import_internal(limit):
+    """Import internal data located in /data/depots/internal"""
+    internal(limit=limit)
+
+
 @click.command()
 def list_all_resources():
     """List all (public and private) resource ids"""
@@ -22,4 +30,4 @@ def list_all_resources():
 
 
 def get_commands():
-    return [import_figshare, list_all_resources]
+    return [import_figshare, import_internal, list_all_resources]
