@@ -22,7 +22,10 @@ class DCORDepotPlugin(p.SingletonPlugin):
         usr_id = pkg["creator_user_id"]
         usr = toolkit.get_action('user_show')(context, {'id': usr_id})
         # resource path
+        jid = "-".join([resource["id"], resource["name"], "symlink"])
         toolkit.enqueue_job(symlink_user_dataset,
                             [pkg, usr, resource],
                             title="Move and symlink user dataset",
-                            rq_kwargs={"timeout": 60})
+                            queue="dcor-short",
+                            rq_kwargs={"timeout": 60,
+                                       "job_id": jid})
